package com.acme.jpa.business;

import java.io.Serializable;
import java.util.List;

/**
 * A generic repository interface for inserting and retrieving entities from the
 * database. Designed with the capabilities of JPA in mind.
 */
public interface Repository
{
   public void create(Serializable entity);
   
   public void delete(Serializable entity);
   
   public <T> T retrieveById(Class<T> entityType, Object primaryKey);
   
   public <T> T retrieveById(Class<T> entityType, Object primaryKey, EntityInitializer<T> callback);
   
   public <T> List<T> retrieveAll(Class<T> entityType);
   
   public <T> List<T> retrieveByQuery(Class<T> entityType, String query, String... params);
   
   public void update(Serializable entity);
   
   public <T extends Serializable> T save(T entity);
   
   public <T extends Serializable> T saveNonManaged(T entity);
   
   public boolean isManaging(Serializable entity);
   
   public void close();
}